/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWGUIQT_DIALOG_NAMESPACE_HPP__
#define __FWGUIQT_DIALOG_NAMESPACE_HPP__

namespace fwGuiQt
{
/**
 * @brief       The namespace fwGuiQt::dialog contains the classes used for container implementation with Qt Library.
 * @namespace   fwGuiQt::dialog
 *
 * @date        2009-2010.
 *
 */
namespace dialog
{

}
}
#endif /* __FWGUIQT_DIALOG_NAMESPACE_HPP__ */
